@@ -9,6 +9,7 @@ Licensed under the GNU General Public License
 
 from datetime import date
 from .sti import stiFromAudio, readwav
+import  numpy as np
 
 __author__ = "Jonathan Polom <jmpolom@wayne.edu>"
 __date__ = date(2011, 4, 22)
@@ -19,18 +20,12 @@ def cal_sti(refFile,testFile):
     refAudio, refRate = readwav(refFile)
     degrAudio, degrRate = readwav(testFile)
 
+    ntimes = 20 // (len(refAudio) // refRate) + 1
+    finalrefAudio, finaldegrAudio = np.repeat(refAudio, ntimes, 0), np.repeat(degrAudio, ntimes, 0)
     # calculate the STI. Visually verify console output.
-    stis = stiFromAudio(refAudio, degrAudio, refRate, name=testFile)
+    stis = stiFromAudio(finalrefAudio, finaldegrAudio, refRate, name=testFile)
     
-    print ("Test Result:",)
-    
-    # test result
-    if abs(stis - 0.63) < 0.002:
-        print ("OK")
-        return 0
-    else:
-        print ("FAILED")
-        return 1
+    return stis
 
 if __name__ == '__main__':
     cal_sti('','')
