@@ -1,10 +1,11 @@
 from operator import methodcaller
 from computeAudioQuality.mainProcess import computeAudioQuality
+from ctypes import  *
 
-
-def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,samplerate=16000,bitwidth=2,channel=1,refOffset=0,testOffset=0):
+def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,samplerate=16000,bitwidth=2,channel=1,refOffset=0,testOffset=0,maxComNLevel=-48.0,speechPauseLevel=-35.0):
     """
-
+            self.maxComNLevel = c_double(kwargs['maxComNLevel'])
+        self.speechPauseLevel = c_double(kwargs['speechPauseLevel'])
     :param metrics: G160/P563/POLQA/PESQ/STOI/STI/PEAQ/SDR/SII/LOUDNESS，必选项
     # G160 无采样率限制；  WAV/PCM输入 ；三端输入: clean、ref、test；无时间长度要求；
     # P563 8000hz(其他采样率会强制转换到8khz)；  WAV/PCM输入 ；单端输入: test；时长 < 20s；
@@ -34,7 +35,9 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,sample
         'bitwidth':bitwidth,
         'channel':channel,
         'refOffset':refOffset,
-        'testOffset':testOffset
+        'testOffset':testOffset,
+        'maxComNLevel':maxComNLevel,
+        "speechPauseLevel":speechPauseLevel
     }
     comAuQUA = computeAudioQuality(**paraDicts)
     return methodcaller(metrics)(comAuQUA)
@@ -42,10 +45,11 @@ def compute_audio_quality(metrics,testFile=None,refFile=None,cleFile=None,sample
 if __name__ == '__main__':
     src = r'E:\martin\files\out16000.wav'
     dst = r'E:\files\result.pcm'
-    test = r'E:\files\out800016000.wav'
-    cle = r'E:\files\out16000_8000.pcm'
-    print(compute_audio_quality('G160',testFile=test,refFile=test,cleFile=cle))
+    ref = r'E:\04_git_clone\audiotestalgorithm\algorithmLib\wavin\noisySignal\16K\20dB\instrument_guzheng_short_20dB_Stationary_WhiteNoise.wav'
+    test = r'E:\04_git_clone\audiotestalgorithm\algorithmLib\wavin\noisySignal\16K\20dB\MusicProtect\Protect_instrument_guzheng_short_20dB_Stationary_WhiteNoise.wav'
+    cle = r'E:\04_git_clone\audiotestalgorithm\algorithmLib\wavin\clean\16K\music\instrument_guzheng_short.wav'
+    print(compute_audio_quality('POLQA',testFile=test,refFile=cle))
     #print(compute_audio_quality('G160', testFile=src,refFile=src,samplerate=16000))
-    print
+
 
     pass
\ No newline at end of file
