@@ -1,10 +1,13 @@
 
 import ctypes
 import sys
-sys.path.append('..')
+import  os
+from os import path
+sys.path.append(os.path.dirname(path.dirname(__file__)))
 print(sys.path)
+
 from ctypes import *
-from formatConvert.wav_pcm import get_data_array
+from  formatConvert.wav_pcm import get_data_array
 
 def resample(infile,target_amplerate):
     data,fs = get_data_array(infile)
